@@ -11,10 +11,11 @@ import collections.abc
 import contextlib
 import copy
 import os
+import sys
 
 abstract = abc.abstractmethod
 
-from clu.constants.consts import DEBUG, PROJECT_NAME, NoDefault
+from clu.constants.consts import DEBUG, PROJECT_NAME, NoDefault, pytuple
 from clu.predicates import attr, tuplize, listify
 from clu.typology import iterlen, ismapping
 from clu.exporting import Exporter
@@ -75,7 +76,8 @@ class KeyMapViewBase(collections.abc.Sequence,
         class, like for good measure.
     """
     
-    __slots__ = ('mapping', 'namespaces', 'prefix')
+    __slots__ = pytuple('weakref') \
+              + tuplize('mapping', 'namespaces', 'prefix')
     
     def __init__(self, mapping, *namespaces):
         """ Initialize a view on a KeyMap instance, for a given namespace """
@@ -324,6 +326,7 @@ class FrozenKeyMapBase(collections.abc.Mapping,
         on up to our own API. You, for your purposes, should employ “FrozenKeyMap”
         (without the “Base”) – q.v. the class definition below, sub.
     """
+    __slots__ = pytuple('weakref')
     
     @abstract
     def namespaces(self):
@@ -1036,46 +1039,47 @@ export(NAMESPACE_SEP, name='NAMESPACE_SEP')
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
 
+from clu.testing.utils import inline, format_environment
+
+@inline.fixture
+def nestedmaps():
+    """ Private nested-dictionary pseudo-fixture """
+    return {'body':   {'declare_i': {'id': {'name': 'i', 'type': 'Identifier'},
+                                            'init': {'type': 'Literal', 'value': 2},
+                                            'type': 'VariableDeclarator'},
+                           'kind': 'var',
+                           'type': 'VariableDeclaration',
+                           'declare_j': {'id': {'name': 'j', 'type': 'Identifier'},
+                                            'init': {'type': 'Literal', 'value': 4},
+                                            'type': 'VariableDeclarator'},
+                           'kind': 'var',
+                           'type': 'VariableDeclaration',
+                           'declare_answer': {'id': {'name': 'answer', 'type': 'Identifier'},
+                                            'init': {'left': {'name': 'i',
+                                                              'type': 'Identifier'},
+                                                     'operator': '*',
+                                                     'right': {'name': 'j',
+                                                               'type': 'Identifier'},
+                                                     'type': 'BinaryExpression'},
+                                            'type': 'VariableDeclarator'},
+                           'kind': 'var',
+                           'type': 'VariableDeclaration'},
+            'type':     'Program'}
+
+@inline.fixture
+def flatdict():
+    """ Private flat-dictionary pseudo-fixture """
+    out = {}
+    for mappingpath in mapwalk(nestedmaps()):
+        *namespaces, key, value = mappingpath
+        nskey = pack_ns(key, *namespaces)
+        out[nskey] = value
+    return out
+
 def test():
     
-    from clu.testing.utils import inline, format_environment
     from pprint import pprint
     
-    @inline.fixture
-    def nestedmaps():
-        """ Private nested-dictionary pseudo-fixture """
-        return {'body':   {'declare_i': {'id': {'name': 'i', 'type': 'Identifier'},
-                                                'init': {'type': 'Literal', 'value': 2},
-                                                'type': 'VariableDeclarator'},
-                               'kind': 'var',
-                               'type': 'VariableDeclaration',
-                               'declare_j': {'id': {'name': 'j', 'type': 'Identifier'},
-                                                'init': {'type': 'Literal', 'value': 4},
-                                                'type': 'VariableDeclarator'},
-                               'kind': 'var',
-                               'type': 'VariableDeclaration',
-                               'declare_answer': {'id': {'name': 'answer', 'type': 'Identifier'},
-                                                'init': {'left': {'name': 'i',
-                                                                  'type': 'Identifier'},
-                                                         'operator': '*',
-                                                         'right': {'name': 'j',
-                                                                   'type': 'Identifier'},
-                                                         'type': 'BinaryExpression'},
-                                                'type': 'VariableDeclarator'},
-                               'kind': 'var',
-                               'type': 'VariableDeclaration'},
-                'type':     'Program'}
-    
-    @inline.fixture
-    def flatdict():
-        """ Private flat-dictionary pseudo-fixture """
-        out = {}
-        for mappingpath in mapwalk(nestedmaps()):
-            *namespaces, key, value = mappingpath
-            nskey = pack_ns(key, *namespaces)
-            out[nskey] = value
-        return out
-    
     @inline.precheck
     def show_nestedmaps():
         print("Nested maps fixture output:")
@@ -1246,8 +1250,18 @@ def test():
         for envline in format_environment():
             print(envline)
     
+    @inline.diagnostic
+    def show_fixture_cache_stats():
+        """ Show the per-fixture-function cache stats """
+        total = len(inline.fixtures)
+        for idx, name in enumerate(inline.fixtures.keys()):
+            if idx > 0:
+                print()
+            print(f"FUNCTION CACHE INFO: {name} ({idx+1} of {total})")
+            print(inline.fixtures[name].cache_info())
+    
     # Run all inline tests:
-    inline.test(100)
+    return inline.test(100)
 
 if __name__ == '__main__':
-    test()
+    sys.exit(test())
