@@ -112,7 +112,8 @@ from clu.predicates import (negate, reverse,
                             allof, anyof, noneof,
                             slots_for)
 
-from clu.typespace import SimpleNamespace, Namespace, types, modulize
+from clu.typespace import types, modulize
+from clu.typespace.namespace import NamespaceRepr, SimpleNamespace, Namespace, isnamespace
 
 from clu.typology import (samelength, differentlength, isunique,
                           istypelist, ismetatypelist, maketypelist, makemetatypelist,
@@ -150,6 +151,8 @@ from clu.abstract import Cloneable, ReprWrapper
 from clu.config.abc import FlatOrderedSet, functional_and, functional_set
 from clu.config.defg import (NAMESPACE_SEP, FrozenKeyMap, KeyMap, FrozenFlat, Flat,
                                                                   FrozenNested, Nested)
+from clu.config.defg import nestedmaps, flatdict
+from clu.config.proxy import KeyMapView, KeyMapProxy
 
 from clu.config.env import Env
 from clu.config.filebase import FileName, FileBase
@@ -169,13 +172,14 @@ from pprint import pprint, pformat
 import sys, os, re
 import argparse
 import collections
-import colorama
 import contextlib
 import copy
 import datetime
 import decimal
 import functools
+import importlib
 import inspect
+import io
 import itertools
 import math
 import operator
@@ -184,8 +188,7 @@ import requests
 import shutil
 import six
 import sysconfig
-import termcolor
-import xerox
+import weakref
 
 from clu.mathematics import (σ, Σ,
                              isdtype, isnumpything,
@@ -232,13 +235,14 @@ __all__ = ('Image',
            'appdirectories',
            'argparse',
            'collections',
-           'colorama',
            'contextlib',
            'copy',
            'datetime',
            'decimal',
            'functools',
+           'importlib',
            'inspect',
+           'io',
            'itertools',
            'math',
            'operator',
@@ -248,9 +252,8 @@ __all__ = ('Image',
            'shutil',
            'six',
            'sysconfig',
-           'termcolor',
            'types',
-           'xerox',
+           'weakref',
            'print_banner',
            'GREEK_STRINGS', 'GREEK_DEFS', 'GREEK_PHONETICS',
                                           'GREEK_STRINGDICT',
@@ -358,7 +361,8 @@ __all__ = ('Image',
            'tuplize', 'uniquify', 'listify', 'union',
            'ancestral', 'ancestral_union',
            'allof', 'anyof', 'noneof',
-           'SimpleNamespace', 'Namespace', 'types', 'modulize',
+           'types', 'modulize',
+           'NamespaceRepr', 'SimpleNamespace', 'Namespace', 'isnamespace',
            'samelength', 'differentlength', 'isunique',
            'istypelist', 'ismetatypelist', 'maketypelist', 'makemetatypelist',
            'isderivative', 'subclasscheck', 'metaclasscheck', 'graceful_issubclass',
@@ -389,6 +393,7 @@ __all__ = ('Image',
            'NAMESPACE_SEP', 'Cloneable', 'ReprWrapper', 'FlatOrderedSet',
            'FrozenKeyMap', 'KeyMap',
            'FrozenFlat', 'FrozenNested',
+           'KeyMapView', 'KeyMapProxy',
            'Flat', 'Nested',
            'Env', 'FileName', 'FileBase',
            'ValidationError', 'hoist',
@@ -416,6 +421,15 @@ else:
     # Extend `__all__`:
     __all__ += ('numpy', 'scipy')
 
+try:
+    import colorama
+    import termcolor
+except (ImportError, SyntaxError):
+    pass
+else:
+    # Extend `__all__`:
+    __all__ += ('colorama', 'termcolor')
+
 try:
     import colorio
     import colormath
@@ -425,6 +439,15 @@ else:
     # Extend `__all__`:
     __all__ += ('colorio', 'colormath')
 
+try:
+    import xerox
+    import zict
+except (ImportError, SyntaxError):
+    pass
+else:
+    # Extend `__all__`:
+    __all__ += ('xerox', 'zict')
+
 try:
     from clu.testing.utils import pout, inline
 except (ImportError, SyntaxError):
@@ -542,6 +565,16 @@ i = 666
 o = object()
 s = 'yo dogg'
 
+sns = SimpleNamespace(yo='dogg', iheard='youlike')
+ns = Namespace(yo='dogg', iheard='youlike')
+
+flat = Flat(flatdict())
+nest = Nested(nestedmaps())
+fview = KeyMapView(flat)
+fprox = KeyMapProxy(flat)
+nview = KeyMapView(nest)
+nprox = KeyMapProxy(nest)
+
 # Remove duplicate and invalid sys.paths:
 if 'pypath' in __all__:
     pypath.remove_invalid_paths()
