@@ -5,7 +5,6 @@ from functools import wraps, lru_cache
 import collections.abc
 import clu.abstract
 import os
-import stopwatch
 import pprint
 import re
 import sys
@@ -46,6 +45,8 @@ def natural_millis(millis):
     return humanize.naturaldelta(
            humanize.time.timedelta(milliseconds=millis))
 
+MOST = 38
+
 @export
 def format_report(aggregated_report, show_buckets=False,
                                      show_annotations=False):
@@ -67,7 +68,7 @@ def format_report(aggregated_report, show_buckets=False,
     root_time = root_time_ms / root_count
     
     entries = [
-        " %s %sx  %.24s [%6.3fs] %.f%%" % (root.ljust(32), "   1",
+        " %s %sx  %.24s [%6.3fs] %.f%%" % (root.ljust(MOST), "   1",
                                              natural_millis(root_time).ljust(12),
                                                             root_time * 0.001,
                                                             100),
@@ -83,12 +84,11 @@ def format_report(aggregated_report, show_buckets=False,
             normal_name = log_name.rpartition('#')[-1]
             short_name = f"{bucket_name}{normal_name}"
         else:
-            # short_name = log_name[log_name.rfind("#") + 1:]
             short_name = log_name.rpartition('#')[-1]
         
         entries.append("%s %s %sx  %.24s [%6.3fs] %.f%%" % (
-            "  " * depth, short_name.ljust(32 - (depth*2)),
-                          str(count).rjust(4),
+            "  " * depth, short_name.ljust(MOST - (depth*2)),
+                          f"{count}".rjust(4),
                           natural_millis(delta_ms).ljust(12),
             delta_ms * 0.001,
             delta_ms / root_time_ms * 100.0,
@@ -140,20 +140,17 @@ def format_environment(environment=None):
                                         max_lines=8,
                                             width=WIDTH - most)
     
-    out = []
     pformat = lambda thing: format_environment.outdenter.sub(r"\g<bracket>",
                                                  printer.pformat(thing))
     
     for key, value in environment.items():
-        jkey = str(key).ljust(most)
+        jkey = f"{key}".ljust(most)
         begin = f"» {jkey} : "
         if key.endswith('PATH') and ':' in value:
             wvalue = pformat(value.split(':'))
         else:
             wvalue = wrapper.fill(value)
-        out.append(f"{begin}{wvalue}")
-    
-    return out
+        yield f"{begin}{wvalue}"
 
 format_environment.outdenter = re.compile(r'^(?P<bracket>[\[\{\(])\s+')
 
@@ -186,10 +183,10 @@ class InlineTester(collections.abc.Set,
                 def apres_testing():
                    # ...
             
-            inline.test() # ‡
+            return inline.test() # ‡
             
             if __name__ == '__main__':
-                test()
+                sys.exit(test())
         
         † This `import` statement specifically instances and returns a
           new copy of the “InlineTester” class, as the “@inline” decorator,
@@ -225,7 +222,7 @@ class InlineTester(collections.abc.Set,
         if iterable is not None:
             self.test_functions.extend(iterable)
     
-    def wrap(self, function, group='execute', groupname='test', newline=False):
+    def wrap(self, function, group='main', groupname='test', newline=False):
         """ Wrap an inline function with timing, banner-printing,
             and all sorts of other useful bookkeeping code used
             internally by the inline testing harness.
@@ -234,7 +231,7 @@ class InlineTester(collections.abc.Set,
         from clu.predicates import item
         from clu.typology import isstring
         from contextlib import ExitStack
-        from pprint import pprint
+        import stopwatch
         
         # Get the name of the decorated function:
         name = nameof(function, default='<unnamed>')
@@ -273,7 +270,7 @@ class InlineTester(collections.abc.Set,
                 out = function(*args, **kwargs)
             
             # If we asked for it, we’ll get it:
-            if newline:
+            if newline and verbose:
                 print()
             
             if verbose:
@@ -295,7 +292,7 @@ class InlineTester(collections.abc.Set,
                 
                 if out is not None:
                     print("» RESULTS:")
-                    pprint(isstring(out) and { 'string' : f"{out!s}" } or out, indent=4)
+                    pprint.pprint(isstring(out) and { 'string' : f"{out!s}" } or out, indent=4)
                     asterisks('~')
                 
                 if timervals:
@@ -313,7 +310,7 @@ class InlineTester(collections.abc.Set,
     
     def __call__(self, function):
         """ Decorate a testing function, marking it as an inline test. """
-        wrapper = self.wrap(function, group='execute',
+        wrapper = self.wrap(function, group='main',
                                       groupname='test',
                                       newline=False)
         
@@ -323,6 +320,21 @@ class InlineTester(collections.abc.Set,
         # Return the test wrapper function:
         return wrapper
     
+    def add_function(self, function, name=None):
+        """ Explictly add a testing function to use as an inline test.
+            Optionally, a name may be specified.
+        """
+        from clu.exporting import determine_name
+        
+        # Stash the old name before assigning the new one:
+        if name is not None:
+            dname = determine_name(function)
+            function.__name__ = function.__qualname__ = name
+            function.__function_name__ = dname
+        
+        # Wrap and return:
+        return self.__call__(function)
+    
     @property
     def precheck(self):
         """ Decorate a preflight-check function.
@@ -408,15 +420,14 @@ class InlineTester(collections.abc.Set,
             test function call (provided by dbx-stopwatch).
         """
         from contextlib import redirect_stdout
+        import stopwatch
         import io
         
         # Count the test functions:
         precount = len(self.prechecks)
         funcount = len(self.test_functions)
         diacount = len(self.diagnostics)
-        
-        # Set up arguments for forwarding:
-        # args = []
+        most = max(precount, funcount, diacount)
         
         # Initialize the stopwatch:
         self.watch = stopwatch.StopWatch()
@@ -430,14 +441,14 @@ class InlineTester(collections.abc.Set,
                     
                     # Call preflight checks each exactly once:
                     for idx, precheck in enumerate(self.prechecks):
-                        precheck(*args, verbose=True, idx=idx, max=precount)
+                        precheck(*args, verbose=True, idx=idx, max=most)
             
             # Main timer for execution times:
-            with self.watch.timer('execute'):
+            with self.watch.timer('main'):
                 
                 # Call testing functions once, initially:
                 for idx, function in enumerate(self.test_functions):
-                    function(*args, verbose=True, idx=idx, max=funcount)
+                    function(*args, verbose=True, idx=idx, max=most)
                 
                 # Call them twice through «adnauseumn» –
                 # Redirecting `stdout` so we only get the
@@ -447,7 +458,7 @@ class InlineTester(collections.abc.Set,
                     with redirect_stdout(iosink):
                         for edx in range(exec_count-1):
                             for idx, function in enumerate(self.test_functions):
-                                function(*args, idx=idx, max=funcount)
+                                function(*args, idx=idx, max=most)
                             iosink.truncate(0)
                     iosink.close()
             
@@ -457,7 +468,7 @@ class InlineTester(collections.abc.Set,
                     
                     # Call diagnostics each exactly once:
                     for idx, diagnostic in enumerate(self.diagnostics):
-                        diagnostic(*args, verbose=True, idx=idx, max=diacount)
+                        diagnostic(*args, verbose=True, idx=idx, max=most)
         
         # REPORT IN:
         report = self.watch.get_last_aggregated_report()
@@ -492,6 +503,9 @@ class InlineTester(collections.abc.Set,
         
         # Clear the stopwatch instance:
         self.watch = None
+        
+        # Return successfully:
+        return os.EX_OK
     
     def __len__(self):
         return len(self.test_functions)
@@ -568,7 +582,6 @@ def test():
     
     # Normally, we’d be like, “from clu.testing.utils import inline”
     # …like, right about say here:
-    # pout = stdpout()
     from clu.fs import pypath
     inline = InlineTester()
     
@@ -593,18 +606,12 @@ def test():
         assert prefix1.exists
         pypath.enhance(prefix0, prefix1)
         
-        # pprint(sys.path)
-        # print()
-        
         from yodogg.config import Env
         from clu.config.defg import Environ
         
         env0 = Env()
         envy = Environ(appname=Env.appname)
         
-        # pprint(envy.flatten())
-        # print()
-        
         for key in env0.keys():
             print(f"» [old] ENVIRONMENT KEY: {key}")
             assert envy[key] == env0[key]
@@ -619,16 +626,12 @@ def test():
     def test_two():
         """ Busywork, mark II. """
         # Fuck around with the CLU app’s environment overrides:
-        # from clu.fs.filesystem import Directory
         from clu.config.env import Env
         from clu.config.defg import Environ
         
         env0 = Env()
         envy = Environ(appname=Env.appname)
         
-        # pprint(envy.flatten())
-        # print()
-        
         for key in env0.keys():
             print(f"» [old] ENVIRONMENT KEY: {key}")
             assert envy[key] == env0[key]
@@ -653,6 +656,7 @@ def test():
     
     @inline
     def test_five_countfiles():
+        """ Check for “clu.testing.utils.countfiles” """
         from clu.typology import isvalidpathlist
         from clu.fs.filesystem import TemporaryDirectory
         
@@ -684,7 +688,7 @@ def test():
         for envline in format_environment():
             print(envline)
     
-    inline.test(100)
+    return inline.test(100)
 
 if __name__ == '__main__':
-    test()
\ No newline at end of file
+    sys.exit(test())
\ No newline at end of file
