@@ -6,6 +6,7 @@ import clu.abstract
 import collections.abc
 import contextlib
 import re
+import sys
 
 from clu.constants.consts import pytuple, NoDefault
 from clu.constants.polyfills import ispyname
@@ -24,8 +25,8 @@ STRINGPAIR = "{!s} : {!s}"
 @export
 class NamespaceRepr(Repr):
     
-    """ Custom Repr-izer for SimpleNamespace and Namespace mappings,
-        which can recursively self-contain.
+    """ Custom Repr-izer for SimpleNamespace and Namespace
+        mappings, which can recursively self-contain.
         
         q.v. cpython docs, http://bit.ly/2r1GQ4l supra.
     """
@@ -34,8 +35,8 @@ class NamespaceRepr(Repr):
                               maxstring=120,
                               maxother=120,
                             **kwargs):
-        """ Initialize a NamespaceRepr, with default params for ‘maxlevel’,
-            ‘maxstring’, and ‘maxother’.
+        """ Initialize a NamespaceRepr, with default params
+            for ‘maxlevel’, ‘maxstring’, and ‘maxother’.
         """
         try:
             super().__init__(*args, **kwargs)
@@ -46,33 +47,60 @@ class NamespaceRepr(Repr):
         self.maxother = maxother
     
     def subrepr(self, thing, level):
+        """ An internal “core” repr helper method. """
         if isnamespace(thing):
             return self.repr1(thing, level - 1)
         return repr(thing)
     
     def primerepr(self, thing, level):
+        """ The internal method for “core” repr production
+            of all namespace descendant types.
+        """
         if len(thing) == 0:
             return "{}"
         elif len(thing) == 1:
             key = tuple(thing.keys())[0]
             item = STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level))
             return f"{{ {item} }}"
-        items = (STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level)) for key in sorted(thing))
+        items = (STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level)) for key in thing)
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
         return f"{{ \n{ts}{total}\n{ls}}}"
     
+    def repr_BaseNamespace(self, thing, level):
+        """ Return the “core” repr for a specific instance of
+            “clu.typespace.namespace.BaseNamespace” – just the
+            stringification of the key-value pairs, without
+            the typename or instance-id adornment.
+        """
+        return self.primerepr(thing, level)
+    
     def repr_SimpleNamespace(self, thing, level):
+        """ Return the “core” repr for a specific instance of
+            “clu.typespace.namespace.SimpleNamespace” – just
+            the stringification of the key-value pairs, without
+            the typename or instance-id adornment.
+        """
         return self.primerepr(thing, level)
     
     def repr_Namespace(self, thing, level):
+        """ Return the “core” repr for a specific instance of
+            “clu.typespace.namespace.Namespace” – just the
+            stringification of the key-value pairs, without
+            the typename or instance-id adornment.
+        """
         return self.primerepr(thing, level)
     
     def shortrepr(self, thing):
+        """ Return the “short” repr of a namespace instance –
+            all whitespace will be condensed to single spaces
+            without newlines.
+        """
         return WHITESPACE.sub(' ', self.repr(thing))
     
     def fullrepr(self, thing, short=False):
+        """ Return the “full” repr of a namespace instance. """
         from clu.repr import fullrepr as fullstringrepr
         if short:
             return fullstringrepr(thing, self.shortrepr(thing))
@@ -85,29 +113,36 @@ nsshortrepr = reprizer.shortrepr
 # NAMESPACES: SimpleNamespace and Namespace
 
 @export
-class SimpleNamespace(collections.abc.Hashable,
-                      collections.abc.Iterable,
-                      clu.abstract.ReprWrapper,
-                      metaclass=clu.abstract.Slotted):
+class BaseNamespace(collections.abc.Set,
+                    collections.abc.Collection,
+                    metaclass=clu.abstract.Slotted):
     
-    """ Implementation courtesy this SO answer:
-        • https://stackoverflow.com/a/37161391/298171
-        
-        Additionally, SimpleNamespace furnishes an `__dir__(…)` method.
-    """
+    """ The abstract base for SimpleNamespace and Namespace. """
     
     __slots__ = pytuple('dict', 'weakref')
     
     def __init__(self, *args, **kwargs):
-        for arg in args:
-            self.__dict__.update(asdict(arg))
-        self.__dict__.update(kwargs)
+        """ Initialize a new namespace instance.
+            
+            One may optionally pass in any number of instances
+            of mapping-ish types, to be merged with the namespace.
+            
+            Any loose keyword arguments will also be merged in.
+        """
+        for mapping in (asdict(arg) for arg in args):
+            for key, value in mapping.items():
+                self.__dict__[key] = value
+        for key, value in kwargs.items():
+            self.__dict__[key] = value
+    
+    def __len__(self):
+        return len(self.__dict__)
     
     def __iter__(self):
         yield from self.__dict__
     
-    def inner_repr(self):
-        return nsrepr(self)
+    def __contains__(self, key):
+        return key in self.__dict__
     
     def __eq__(self, other):
         return self.__dict__ == asdict(other)
@@ -115,22 +150,38 @@ class SimpleNamespace(collections.abc.Hashable,
     def __ne__(self, other):
         return self.__dict__ != asdict(other)
     
+    def __dir__(self):
+        """ Get a list with all the stringified keys in the namespace. """
+        return [str(key) for key in self if key not in ('get', 'pop', 'update')]
+    
+    def __repr__(self):
+        return reprizer.fullrepr(self)
+    
+    def __bool__(self):
+        return bool(self.__dict__)
+
+@export
+class SimpleNamespace(BaseNamespace,
+                      collections.abc.Hashable):
+    
+    """ Implementation courtesy this SO answer:
+        • https://stackoverflow.com/a/37161391/298171
+        
+        Additionally, SimpleNamespace furnishes an `__hash__(…)` method.
+    """
+    
     def __hash__(self):
         return hash(tuple(self.__dict__.keys()) +
                     tuple(self.__dict__.values()))
-    
-    def __dir__(self):
-        """ Get a list with all the stringified keys in the namespace. """
-        return [str(key) for key in sorted(self) if key not in ('inner_repr', 'get', 'pop', 'update')]
 
 @export
-class Namespace(SimpleNamespace,
+class Namespace(BaseNamespace,
                 collections.abc.MutableMapping,
                 contextlib.AbstractContextManager):
     
     """ Namespace adds the `get(…)`, `__len__()`, `__contains__(…)`, `__getitem__(…)`,
-        `__setitem__(…)`, `__add__(…)`, and `__bool__()` methods to its ancestor class
-        implementation SimpleNamespace.
+        `__setitem__(…)`, and `__add__(…)` methods to its ancestor class
+        implementation BaseNamespace.
         
         Since it implements a `get(…)` method, Namespace instances can be passed
         to `merge(…)` – q.v. `merge(…)` function definition supra.
@@ -173,12 +224,6 @@ class Namespace(SimpleNamespace,
                        exc_tb=None):
         return exc_type is None
     
-    def __len__(self):
-        return len(self.__dict__)
-    
-    def __contains__(self, key):
-        return key in self.__dict__
-    
     def __getitem__(self, key):
         return self.__dict__.__getitem__(key)
     
@@ -206,29 +251,25 @@ class Namespace(SimpleNamespace,
             return NotImplemented
         self.__dict__.update(asdict(operand))
         return self
-    
-    def __or__(self, operand):
-        return self.__add__(operand)
-    
-    def __ror__(self, operand):
-        return self.__radd__(operand)
-    
-    def __ior__(self, operand):
-        return self.__iadd__(operand)
-    
-    def __bool__(self):
-        return bool(self.__dict__)
 
 @export
 def isnamespace(thing):
+    """ isnamespace(thing) → boolean predicate,
+        True if the name of the type of “thing”
+        is amongst those of the quote-unquote
+        “Namespace tower”, as defined in the
+        module “clu.typespace.namespace”
+    """
     from clu.typology import subclasscheck
-    return subclasscheck(thing, (SimpleNamespace, Namespace))
+    return subclasscheck(thing, (BaseNamespace,
+                               SimpleNamespace,
+                                     Namespace))
 
 with exporter as export:
     
     export(reprizer,    name='reprizer')
-    export(nsrepr,      name='nsrepr')
     export(nsshortrepr, name='nsshortrepr')
+    export(nsrepr,      name='nsrepr',          doc="Return the “core” repr for any descendant namespace type.")
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
@@ -237,6 +278,20 @@ def test():
     
     from clu.testing.utils import inline
     
+    @inline.fixture
+    def flat_dict():
+        return {
+            'yo'        : "dogg",
+            'i_heard'   : "you like",
+            'nested'    : "dicts",
+            'so'        : "we put dicts in your dicts"
+        }
+    
+    @inline.fixture
+    def shorty_repr():
+        return "SimpleNamespace({ yo : 'dogg', i_heard : 'you like', " \
+               "nested : 'dicts', so : 'we put dicts in your dicts' })"
+    
     @inline
     def test_one():
         """ Implicit recursive namespaces """
@@ -253,9 +308,6 @@ def test():
         ROOT.yo.dogg = "yo dogg"
         ROOT.yo.wat = "¡WAT!"
         
-        # print("ROOT NAMESPACE:")
-        # print(ROOT)
-        
         assert ROOT.other.additional        == "«additional»"
         assert ROOT.other.considerations    == "…"
         assert ROOT.yo.dogg                 == "yo dogg"
@@ -267,7 +319,16 @@ def test():
         
         return ROOT
     
-    inline.test(100)
+    @inline
+    def test_two():
+        """ SimpleNamespace sanity checks """
+        from clu.repr import chop_instance_repr
+        
+        sn = SimpleNamespace(flat_dict())
+        assert dir(sn) == ['i_heard', 'nested', 'so', 'yo']
+        assert chop_instance_repr(reprizer.fullrepr(sn, short=True)) == shorty_repr()
+    
+    return inline.test(100)
 
 if __name__ == '__main__':
-    test()
+    sys.exit(test())
